#!/bin/ksh
#set -x

PATCH_NAME=P410A-02M

myid=$(id | cut -f 2 -d '(' | cut -f 1 -d ')')
if [[ ${myid} != "root" ]]; then
   print "You must be root to install this patch."
   return 1
fi

PATCH_DIR=$(dirname ${0})
cd ${PATCH_DIR}
PATCH_DIR=$(pwd)

if [[ ! -a data/all_files.list ]]; then
   print "Error: can't find ${PATCH_DIR}/data/all_files.list"
   return 1
fi

if [[ ! -a data/UNDO.tar.Z ]]; then
   ( rm data/UNDO_files.* 2>&1 ) >/dev/null
   if [[ ! -a data/UNDO_files.list ]]; then
      for filename in $(cat data/all_files.list); do
         if [[ -f /usr/ldap/${filename} ]]; then
            print ${filename} >>data/UNDO_files.list
            cksum /usr/ldap/${filename} >>data/UNDO_files.sum
         fi
      done
   fi

   print "Backing up existing files..."
   cd /usr/ldap
   if ( ! tar cf ${PATCH_DIR}/data/UNDO.tar $(cat ${PATCH_DIR}/data/UNDO_files.list) ) ; then
      print "\nUnable to backup existing files."
      print "The patch will not be installed."
      return 1
   fi
   cd ${PATCH_DIR}
   compress data/UNDO.tar
fi

if [[ ! -a data/UNDO_files.list ]]; then
   # This should never happen, but just in case...
   print "Regenerating patch file list..."
   if ( ! compress -cd data/UNDO.tar.Z | tar tf - >data/UNDO_files.list ); then
      print "\nUnable to generate filelist."
      print "the patch will not be installed."
      return 1
   fi
fi

print "Installing patch files..."
slibclean
( rm -rf tmp 2>&1 ) >/dev/null
mkdir tmp
cd tmp

if ( ! compress -cd ../data/patch.tar.Z | tar xf - bin/${PATCH_NAME}Readme.txt bin/${PATCH_NAME}.txt $(cat ../data/UNDO_files.list) ); then
   print "\nError applying patch"
   print "Restoring backup files..."
   cd ..
   rm -rf tmp
   cd /usr/ldap
   (rm -rf bin/${PATCH_NAME}* 2>&1) >/dev/null
   compress -cd ${PATCH_DIR}/data/UNDO.tar.Z | tar xf -
   print "The patch could not be installed."
   return 1
fi

cp -r * /usr/ldap
cd ..
rm -rf tmp
( rm data/PATCH_files.* 2>&1 ) >/dev/null
for filename in bin/${PATCH_NAME}Readme.txt bin/${PATCH_NAME}.txt $(cat data/UNDO_files.list); do
   cksum /usr/ldap/${filename} >>data/PATCH_files.sum
done

print "The patch has been successfully installed."
print "\n(Note: The patch can be uninstalled by running rejectPatch.sh"
print "       only if data/UNDO.tar.Z is not removed. )"

